@@ -220,6 +220,10 @@ main (int argc, char **argv)
   assert_match_anchored (DEFS URLPATH, "/().", "/()");
   assert_match_anchored (DEFS URLPATH, "/", ENTIRE);
   assert_match_anchored (DEFS URLPATH, "", ENTIRE);
+  assert_match_anchored (DEFS URLPATH, "?", ENTIRE);
+  assert_match_anchored (DEFS URLPATH, "?param=value", ENTIRE);
+  assert_match_anchored (DEFS URLPATH, "#", ENTIRE);
+  assert_match_anchored (DEFS URLPATH, "#anchor", ENTIRE);
   assert_match_anchored (DEFS URLPATH, "/php?param[]=value1&param[]=value2", ENTIRE);
   assert_match_anchored (DEFS URLPATH, "/foo?param1[index1]=value1&param2[index2]=value2", ENTIRE);
   assert_match_anchored (DEFS URLPATH, "/[[[]][]]", ENTIRE);
@@ -237,6 +241,7 @@ main (int argc, char **argv)
   assert_match (REGEX_URL_AS_IS, "Trailing ellipsis http://foo/bar.html...",    "http://foo/bar.html");
   assert_match (REGEX_URL_AS_IS, "Trailing comma http://foo/bar,baz,",          "http://foo/bar,baz");
   assert_match (REGEX_URL_AS_IS, "Trailing semicolon http://foo/bar;baz;",      "http://foo/bar;baz");
+  assert_match (REGEX_URL_AS_IS, "Trailing colon http://foo/bar:baz:",          "http://foo/bar:baz");
   assert_match (REGEX_URL_AS_IS, "See <http://foo/bar>",                        "http://foo/bar");
   assert_match (REGEX_URL_AS_IS, "<http://foo.bar/asdf.qwer.html>",             "http://foo.bar/asdf.qwer.html");
   assert_match (REGEX_URL_AS_IS, "Go to http://192.168.1.1.",                   "http://192.168.1.1");
@@ -270,6 +275,18 @@ main (int argc, char **argv)
   assert_match (REGEX_URL_AS_IS, "http://1.2.3.4:70000",                "http://1.2.3.4");  /* TODO: can/should we totally abort here? */
   assert_match (REGEX_URL_AS_IS, "http://[dead::beef:111.222.333.444]", nullptr);
 
+  /* '?' or '#' without '/', #7888 */
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar?",                  ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar?param=value",       ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar:12345?param=value", ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://1.2.3.4?param=value",       ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://[dead::beef]?param=value",  ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar#",                  ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar#anchor",            ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://foo.bar:12345#anchor",      ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://1.2.3.4#anchor",            ENTIRE);
+  assert_match (REGEX_URL_AS_IS, "http://[dead::beef]#anchor",       ENTIRE);
+
   /* Username, password */
   assert_match (REGEX_URL_AS_IS, "http://joe@example.com",                 ENTIRE);
   assert_match (REGEX_URL_AS_IS, "http://user.name:sec.ret@host.name",     ENTIRE);
